==> flutter_vasat-0.0.3.tar.gz: lib/models/device.dart <==
import 'dart:io';

import 'package:device_info/device_info.dart';
import 'package:flutter_vasat/models/device_type.dart';
import 'package:flutter_vasat/models/vasat_model.dart';

class Device extends VasatModel<Device> {

  String remoteID;
  String simCarrier;
  String networkCarrier;
  bool allowPush;
  String deviceFeatures;
  double lastLatitude;
  double lastLongitude;
  DeviceType deviceType;
  String lastAppVersionCode;
  String lastAppVersionName;
  String pushRegId;
  bool pushRegIdSentToServer;

  Device({Map<String, dynamic> json, this.remoteID, this.simCarrier, this.networkCarrier, this.allowPush = false, this.deviceFeatures, this.deviceType, this.lastAppVersionCode, this.lastAppVersionName, this.pushRegIdSentToServer, this.pushRegId}) {
    fromJson(json);
    super.fromJson(json);
  }

  factory Device.fromJson(Map<String, dynamic> json) {
    return Device(json:json);
  }

  static Future<Device> mkDevice() async {
    Device device;
    DeviceInfoPlugin deviceInfo = DeviceInfoPlugin();

    if (Platform.isAndroid) {
      AndroidDeviceInfo androidInfo = await deviceInfo.androidInfo;
      device = Device(
        remoteID: androidInfo.androidId,
        deviceType: DeviceType(
            deviceMake: androidInfo.brand,
            deviceModel: androidInfo.model,
            deviceOSName: "Android",
            deviceOSVersion: "${androidInfo.version.codename} ${androidInfo.version.sdkInt} ${androidInfo.version.securityPatch}"
        ),
      );
      device.name = androidInfo.fingerprint;
    } else if (Platform.isIOS) {
      IosDeviceInfo iosInfo = await deviceInfo.iosInfo;
      device = Device(
        remoteID: iosInfo.identifierForVendor,
        deviceType: DeviceType(
            deviceMake: iosInfo.systemName,
            deviceModel: iosInfo.model,
            deviceOSName: "IOS",
            deviceOSVersion: iosInfo.systemVersion
        ),
      );
      device.name = iosInfo.name;
    } else {
      device = Device(
        deviceType: DeviceType(deviceMake: "UNKNOWN",deviceModel: "UNKNOWN",deviceOSName: "UNKNOWN",deviceOSVersion: "UNKNOWN"),
      );
      device.name = "UNKNOWN";
    }
    return device;

  }

  @override
  fromJson(Map<String, dynamic> json) {
    if (json != null) {
      remoteID = json['remoteID'];
      simCarrier = json['simCarrier'];
      networkCarrier = json['networkCarrier'];
      allowPush = json['allowPush'];
      deviceFeatures = json['deviceFeatures'];
      lastLatitude = json['lastLatitude'];
      lastLongitude = json['lastLongitude'];
      deviceType = DeviceType.fromJson(json['deviceType']);
      lastAppVersionCode = json['lastAppVersionCode'];
      lastAppVersionName = json['lastAppVersionName'];
      pushRegId = json['pushRegId'];
      pushRegIdSentToServer = json['pushRegIdSentToServer'];
    }
  }


  @override
  Map<String, dynamic> toJson() {
    var obj = super.toJson();
    obj["remoteID"] = remoteID;
    obj["simCarrier"] = simCarrier;
    obj["networkCarrier"] = networkCarrier;
    obj["allowPush"] = allowPush;
    obj["deviceFeatures"] = deviceFeatures;
    obj["lastLatitude"] = lastLatitude;
    obj["lastLongitude"] = lastLongitude;
    obj["deviceType"] = deviceType.toJson();
    obj["lastAppVersionCode"] = lastAppVersionCode;
    obj["lastAppVersionName"] = lastAppVersionName;
    obj["pushRegId"] = pushRegId;
    obj["pushRegIdSentToServer"] = pushRegIdSentToServer;
    return obj;
  }

  @override
  Device copyFromJson(Map<String, dynamic> json) {
    return Device.fromJson(json);
  }


}

==> flutter_vasat-0.0.6.tar.gz: lib/models/device.dart <==
import 'dart:io';
import 'package:device_info_plus/device_info_plus.dart';
import 'device_type.dart';
import 'vasat_model.dart';

class Device extends VasatModel<Device> {

  String? remoteID;
  String? simCarrier;
  String? networkCarrier;
  bool allowPush;
  String? deviceFeatures;
  double? lastLatitude;
  double? lastLongitude;
  DeviceType? deviceType;
  String? lastAppVersionCode;
  String? lastAppVersionName;
  String? pushRegId;
  bool pushRegIdSentToServer;

  Device({Map<String, dynamic>? json, this.remoteID, this.simCarrier, this.networkCarrier, this.allowPush = false, this.deviceFeatures, this.deviceType, this.lastAppVersionCode, this.lastAppVersionName, this.pushRegIdSentToServer = false, this.pushRegId}) {
    fromJson(json);
    super.fromJson(json);
  }

  factory Device.fromJson(Map<String, dynamic>? json) {
    return Device(json:json);
  }

  static Future<Device> mkDevice() async {
    Device device;
    DeviceInfoPlugin deviceInfo = DeviceInfoPlugin();

    if (Platform.isAndroid) {
      AndroidDeviceInfo androidInfo = await deviceInfo.androidInfo;
      device = Device(
        remoteID: androidInfo.androidId,
        deviceType: DeviceType(
            deviceMake: androidInfo.brand,
            deviceModel: androidInfo.model,
            deviceOSName: "Android",
            deviceOSVersion: "${androidInfo.version.codename} ${androidInfo.version.sdkInt} ${androidInfo.version.securityPatch}"
        ),
      );
      device.name = androidInfo.fingerprint;
    } else if (Platform.isIOS) {
      IosDeviceInfo iosInfo = await deviceInfo.iosInfo;
      device = Device(
        remoteID: iosInfo.identifierForVendor,
        deviceType: DeviceType(
            deviceMake: iosInfo.systemName,
            deviceModel: iosInfo.model,
            deviceOSName: "IOS",
            deviceOSVersion: iosInfo.systemVersion
        ),
      );
      device.name = iosInfo.name;
    } else {
      device = Device(
        deviceType: DeviceType(deviceMake: "UNKNOWN",deviceModel: "UNKNOWN",deviceOSName: "UNKNOWN",deviceOSVersion: "UNKNOWN"),
      );
      device.name = "UNKNOWN";
    }
    return device;

  }

  @override
  fromJson(Map<String, dynamic>? json) {
    if (json != null) {
      remoteID = json['remoteID'];
      simCarrier = json['simCarrier'];
      networkCarrier = json['networkCarrier'];
      allowPush = json['allowPush'];
      deviceFeatures = json['deviceFeatures'];
      lastLatitude = json['lastLatitude'];
      lastLongitude = json['lastLongitude'];
      deviceType = DeviceType.fromJson(json['deviceType']);
      lastAppVersionCode = json['lastAppVersionCode'];
      lastAppVersionName = json['lastAppVersionName'];
      pushRegId = json['pushRegId'];
      pushRegIdSentToServer = json['pushRegIdSentToServer'];
    }
  }


  @override
  Map<String, dynamic> toJson() {
    var obj = super.toJson();
    obj["remoteID"] = remoteID;
    obj["simCarrier"] = simCarrier;
    obj["networkCarrier"] = networkCarrier;
    obj["allowPush"] = allowPush;
    obj["deviceFeatures"] = deviceFeatures;
    obj["lastLatitude"] = lastLatitude;
    obj["lastLongitude"] = lastLongitude;
    obj["deviceType"] = deviceType?.toJson();
    obj["lastAppVersionCode"] = lastAppVersionCode;
    obj["lastAppVersionName"] = lastAppVersionName;
    obj["pushRegId"] = pushRegId;
    obj["pushRegIdSentToServer"] = pushRegIdSentToServer;
    return obj;
  }

  @override
  Device copyFromJson(Map<String, dynamic> json) {
    return Device.fromJson(json);
  }


}
